import pkg_resources

__all__ = ["CHROMOSOME_DATA", "COLOR_MAP", "IMPORTANT_GENES", "GAPS", "GENES"]

# Data copied from conumee
GAPS = pkg_resources.resource_filename("mepylome", "data/gaps.csv.gz")

# HG19 Gene data downloaded from:
# https://grch37.ensembl.org/biomart/martview
GENES = pkg_resources.resource_filename("mepylome", "data/hg19_genes.tsv.gz")

CHROMOSOME_DATA = {
    "name": [
        "chr1",
        "chr2",
        "chr3",
        "chr4",
        "chr5",
        "chr6",
        "chr7",
        "chr8",
        "chr9",
        "chr10",
        "chr11",
        "chr12",
        "chr13",
        "chr14",
        "chr15",
        "chr16",
        "chr17",
        "chr18",
        "chr19",
        "chr20",
        "chr21",
        "chr22",
        "chrX",
        "chrY",
    ],
    "len": [
        249250621,
        243199373,
        198022430,
        191154276,
        180915260,
        171115067,
        159138663,
        146364022,
        141213431,
        135534747,
        135006516,
        133851895,
        115169878,
        107349540,
        102531392,
        90354753,
        81195210,
        78077248,
        59128983,
        63025520,
        48129895,
        51304566,
        155270560,
        59373566,
    ],
    "centromere_start": [
        121535434,
        92326171,
        90504854,
        49660117,
        46405641,
        58830166,
        58054331,
        43838887,
        47367679,
        39254935,
        51644205,
        34856694,
        16000000,
        16000000,
        17000000,
        35335801,
        22263006,
        15460898,
        24681782,
        26369569,
        11288129,
        13000000,
        58632012,
        10104553,
    ],
    "centromere_end": [
        124535434,
        95326171,
        93504854,
        52660117,
        49405641,
        61830166,
        61054331,
        46838887,
        50367679,
        42254935,
        54644205,
        37856694,
        19000000,
        19000000,
        20000000,
        38335801,
        25263006,
        18460898,
        27681782,
        29369569,
        14288129,
        16000000,
        61632012,
        13104553,
    ],
}

IMPORTANT_GENES = [
    "BRD4",
    "CDK4",
    "CDKN2A",
    "CDKN2B",
    "EGFR",
    "ERBB2",
    "IL13RA2",
    "KIT",
    "MDM4",
    "MET",
    "NF1",
    "NF2",
    "NTRK3",
    "NUTM1",
    "PDGFRA",
    "PTEN",
    "RB1",
    "SOX2",
]


COLOR_MAP = {
    "ADREN_CA": "rgb(98, 184, 166)",
    "ADREN_CA_CELLC": "rgb(255, 255, 128)",
    "AFH": "rgb(27, 90, 248)",
    "AFX_PDS": "rgb(45, 66, 203)",
    "ALMO_MPC": "rgb(99, 222, 233)",
    "AMH_UMB": "rgb(118, 188, 19)",
    "AML": "rgb(246, 182, 123)",
    "ANA_PA": "rgb(128, 128, 128)",
    "APP_CONTR": "rgb(101, 245, 110)",
    "APP_GOBCOID": "rgb(255, 255, 0)",
    "APP_ITIS": "rgb(191, 249, 253)",
    "APP_NET": "rgb(128, 128, 128)",
    "AS": "rgb(253, 73, 74)",
    "ASPS": "rgb(166, 73, 172)",
    "ATRT_MYC": "rgb(172, 129, 43)",
    "ATRT_SHH": "rgb(251, 33, 135)",
    "ATRT_TYR": "rgb(60, 210, 2)",
    "A_IDH": "rgb(8, 5, 166)",
    "A_IDH_HG": "rgb(8, 177, 250)",
    "BLADURO_CA": "rgb(130, 34, 185)",
    "BLADURO_CA_CELLC": "rgb(128, 0, 0)",
    "BR_CA": "rgb(43, 209, 220)",
    "BR_CA_CELLC": "rgb(39, 247, 32)",
    "BR_FAD": "rgb(139, 57, 8)",
    "CARCI_A_LUN": "rgb(107, 251, 221)",
    "CAVER": "rgb(245, 108, 173)",
    "CB": "rgb(89, 115, 252)",
    "CCS": "rgb(216, 5, 94)",
    "CCSK": "rgb(162, 216, 238)",
    "CERAD_CA": "rgb(61, 253, 76)",
    "CERSQ_CA": "rgb(1, 35, 3)",
    "CERSQ_CA_CELLC": "rgb(175, 49, 54)",
    "CERSQ_CA_HPV": "rgb(0, 35, 168)",
    "CHGL": "rgb(172, 129, 43)",
    "CHOL_CA": "rgb(50, 2, 129)",
    "CHOL_CA_CELLC": "rgb(246, 182, 123)",
    "CHORCA": "rgb(130, 34, 185)",
    "CHORD": "rgb(104, 219, 175)",
    "CHORDM": "rgb(128, 255, 0)",
    "CHORD_DD": "rgb(99, 222, 233)",
    "CN": "rgb(25, 109, 207)",
    "CNS_EPCYST": "rgb(247, 214, 61)",
    "CNS_NB_FOXR2": "rgb(206, 41, 79)",
    "COL_CA": "rgb(179, 254, 183)",
    "COL_CA_CELLC": "rgb(192, 20, 9)",
    "CONTR_ADENOPIT": "rgb(205, 26, 254)",
    "CONTR_ADREN": "rgb(76, 159, 211)",
    "CONTR_BLA": "rgb(255, 0, 128)",
    "CONTR_BREAST": "rgb(2, 178, 134)",
    "CONTR_CEBM": "rgb(2, 178, 134)",
    "CONTR_CERV": "rgb(51, 5, 7)",
    "CONTR_CHOL": "rgb(45, 66, 203)",
    "CONTR_COL": "rgb(3, 171, 6)",
    "CONTR_ESO": "rgb(63, 209, 74)",
    "CONTR_HEMI": "rgb(98, 184, 166)",
    "CONTR_HN": "rgb(157, 162, 1)",
    "CONTR_HYPTHAL": "rgb(250, 155, 61)",
    "CONTR_INFLAM": "rgb(89, 42, 218)",
    "CONTR_KIDNEY": "rgb(250, 155, 61)",
    "CONTR_LIVER": "rgb(93, 129, 209)",
    "CONTR_LUNG": "rgb(2, 31, 205)",
    "CONTR_OVA": "rgb(0, 35, 168)",
    "CONTR_PINEAL": "rgb(202, 232, 51)",
    "CONTR_PONS": "rgb(172, 204, 55)",
    "CONTR_PR": "rgb(27, 190, 42)",
    "CONTR_REACT": "rgb(255, 255, 0)",
    "CONTR_SKIN": "rgb(255, 255, 128)",
    "CONTR_SOFT": "rgb(164, 70, 28)",
    "CONTR_STOM": "rgb(181, 251, 132)",
    "CONTR_THYM": "rgb(128, 255, 255)",
    "CONTR_THYR": "rgb(41, 62, 241)",
    "CONTR_TUB": "rgb(129, 154, 59)",
    "CONTR_WM": "rgb(150, 203, 163)",
    "CPH_ADM": "rgb(112, 49, 248)",
    "CPH_PAP": "rgb(106, 103, 29)",
    "CSA_A": "rgb(116, 85, 73)",
    "CSA_B": "rgb(221, 113, 15)",
    "CSA_CC": "rgb(246, 169, 203)",
    "CSA_IDH_A": "rgb(233, 221, 113)",
    "CSA_IDH_B": "rgb(213, 0, 233)",
    "CSA_IDH_MUT_A": "rgb(2, 178, 134)",
    "CSA_MES": "rgb(2, 31, 205)",
    "CTRL_BLOOD": "rgb(253, 179, 6)",
    "CTRL_MUS": "rgb(4, 131, 79)",
    "CTRL_REA": "rgb(255, 255, 128)",
    "DDLS": "rgb(13, 205, 84)",
    "DFSP": "rgb(254, 41, 255)",
    "DLBCL": "rgb(0, 128, 255)",
    "DLBCL_ABC": "rgb(172, 204, 55)",
    "DLBCL_CELLC": "rgb(254, 93, 229)",
    "DLBCL_GCB": "rgb(172, 129, 43)",
    "DLGNT": "rgb(137, 141, 212)",
    "DMG_K27": "rgb(49, 62, 123)",
    "DNADEG": "rgb(25, 109, 207)",
    "DS": "rgb(162, 216, 238)",
    "DSRCT": "rgb(165, 99, 133)",
    "DTFM": "rgb(0, 128, 0)",
    "EFT_CIC": "rgb(166, 186, 118)",
    "EHE": "rgb(225, 67, 234)",
    "ELST": "rgb(254, 216, 190)",
    "EMBCA_T": "rgb(247, 214, 61)",
    "EMCS": "rgb(253, 73, 74)",
    "ENB_A": "rgb(128, 255, 0)",
    "ENB_B": "rgb(166, 186, 118)",
    "ENDOM_CA": "rgb(1, 145, 200)",
    "ENDOM_CA_CELLC": "rgb(1, 11, 100)",
    "EPN_MPE": "rgb(246, 165, 255)",
    "EPN_PF_A": "rgb(255, 255, 0)",
    "EPN_PF_B": "rgb(125, 199, 202)",
    "EPN_RELA": "rgb(4, 131, 79)",
    "EPN_SPINE": "rgb(205, 211, 248)",
    "EPN_YAP": "rgb(230, 73, 178)",
    "ES": "rgb(199, 208, 201)",
    "ESO_CA": "rgb(148, 40, 133)",
    "ESO_CA_AD": "rgb(216, 5, 175)",
    "ESO_CA_CELLC": "rgb(137, 141, 212)",
    "ESO_CA_SQ": "rgb(225, 67, 234)",
    "ESS_HG": "rgb(0, 0, 255)",
    "ESS_LG": "rgb(55, 161, 2)",
    "ETMR": "rgb(45, 218, 33)",
    "EWS": "rgb(101, 245, 110)",
    "FDY": "rgb(172, 129, 43)",
    "FIDYS": "rgb(114, 194, 122)",
    "GBM_CELLC": "rgb(3, 101, 156)",
    "GBM_G34": "rgb(255, 255, 128)",
    "GBM_LOW": "rgb(4, 131, 79)",
    "GBM_MES": "rgb(233, 221, 113)",
    "GBM_MID": "rgb(43, 172, 68)",
    "GBM_MYCN": "rgb(0, 85, 27)",
    "GBM_NOS": "rgb(209, 241, 7)",
    "GBM_RTK_I": "rgb(61, 118, 128)",
    "GBM_RTK_II": "rgb(156, 4, 166)",
    "GBM_RTK_III": "rgb(246, 165, 255)",
    "GCFB_DFSP": "rgb(251, 43, 7)",
    "GCTB": "rgb(88, 127, 95)",
    "GERMI_CNS": "rgb(220, 2, 4)",
    "GIST": "rgb(55, 24, 251)",
    "GLOAN": "rgb(0, 0, 255)",
    "GN": "rgb(1, 11, 100)",
    "HCA": "rgb(191, 249, 253)",
    "HCC": "rgb(60, 210, 2)",
    "HCC_CELLC": "rgb(156, 98, 254)",
    "HGNET_BCOR": "rgb(89, 42, 218)",
    "HGNET_MN1": "rgb(30, 151, 115)",
    "HGNET_NOS6": "rgb(175, 135, 149)",
    "HMB": "rgb(16, 57, 27)",
    "HNSQ_CA": "rgb(146, 253, 79)",
    "HODG_CL": "rgb(63, 209, 74)",
    "HODG_NS": "rgb(211, 138, 71)",
    "HPAP": "rgb(78, 48, 63)",
    "IFS": "rgb(125, 199, 202)",
    "IHG": "rgb(162, 222, 100)",
    "IMFT": "rgb(157, 162, 1)",
    "IMT": "rgb(61, 253, 76)",
    "IMTER_T": "rgb(206, 41, 79)",
    "Kaposi": "rgb(139, 57, 8)",
    "LCH": "rgb(221, 113, 15)",
    "LGFMS": "rgb(246, 165, 255)",
    "LGG": "rgb(114, 194, 122)",
    "LGG_DIG/DIA": "rgb(0, 128, 0)",
    "LGG_DNT": "rgb(116, 85, 73)",
    "LGG_GG": "rgb(0, 35, 168)",
    "LGG_MYB": "rgb(114, 48, 118)",
    "LGG_PA_GG_ST": "rgb(221, 113, 15)",
    "LGG_PA_MID": "rgb(184, 92, 84)",
    "LGG_PA_PF": "rgb(39, 247, 32)",
    "LGG_RGNT": "rgb(172, 47, 221)",
    "LGG_SEGA": "rgb(246, 169, 203)",
    "LIPN": "rgb(1, 161, 170)",
    "LIPO": "rgb(246, 182, 123)",
    "LMO": "rgb(209, 241, 7)",
    "LMS": "rgb(92, 108, 170)",
    "LYMPHO": "rgb(175, 135, 149)",
    "LYM_B_LPL": "rgb(216, 5, 175)",
    "LYM_B_LPL_DLBCL": "rgb(162, 222, 100)",
    "LYM_B_MZL_DLBCL": "rgb(0, 0, 255)",
    "LYM_B_MZL_EYE": "rgb(249, 207, 251)",
    "LYM_B_MZL_LN": "rgb(255, 128, 128)",
    "LYM_B_MZL_LUN": "rgb(184, 92, 84)",
    "LYM_B_MZL_MALT": "rgb(238, 254, 53)",
    "LYM_B_MZL_NOS": "rgb(172, 47, 221)",
    "LYM_B_MZL_SP": "rgb(225, 67, 234)",
    "LYM_B_MZL_STO": "rgb(137, 141, 212)",
    "LYM_FOL_HG": "rgb(224, 26, 46)",
    "LYM_FOL_LG": "rgb(27, 238, 154)",
    "LYM_MAN": "rgb(139, 57, 8)",
    "LYM_MAN_BLA": "rgb(116, 85, 73)",
    "MATTER_T": "rgb(1, 145, 200)",
    "MB_G3": "rgb(107, 251, 221)",
    "MB_G4": "rgb(1, 35, 3)",
    "MB_SHH_CHL_AD": "rgb(116, 85, 73)",
    "MB_SHH_INF": "rgb(79, 180, 238)",
    "MB_WNT": "rgb(253, 89, 3)",
    "MELAN": "rgb(62, 123, 8)",
    "MELAN_CUT": "rgb(165, 99, 133)",
    "MELAN_CUT_CELLC": "rgb(69, 1, 215)",
    "MELAN_UVE": "rgb(231, 153, 116)",
    "MELAN_UVE_CELLC": "rgb(130, 34, 185)",
    "MELCYT": "rgb(213, 0, 233)",
    "MEL_CUT": "rgb(139, 184, 80)",
    "MERKELCA": "rgb(209, 241, 7)",
    "MESOT": "rgb(255, 1, 62)",
    "MESOT_CELLC": "rgb(105, 1, 63)",
    "MLS": "rgb(78, 48, 63)",
    "MNG": "rgb(175, 135, 149)",
    "MNG_BEN-1": "rgb(224, 202, 156)",
    "MNG_BEN-2": "rgb(35, 68, 78)",
    "MNG_BEN-3": "rgb(60, 210, 2)",
    "MNG_CC": "rgb(57, 144, 53)",
    "MNG_INT-A": "rgb(99, 162, 5)",
    "MNG_INT-B": "rgb(253, 179, 6)",
    "MNG_MAL": "rgb(0, 35, 168)",
    "MO": "rgb(1, 145, 200)",
    "MP": "rgb(157, 162, 1)",
    "MPNST": "rgb(254, 51, 193)",
    "MPNST_HG": "rgb(162, 222, 100)",
    "MPNST_LG": "rgb(250, 155, 61)",
    "MRT": "rgb(114, 194, 122)",
    "MYFS": "rgb(251, 43, 7)",
    "NBL": "rgb(238, 254, 53)",
    "NE_CA": "rgb(150, 203, 163)",
    "NFA": "rgb(10, 89, 60)",
    "NFB": "rgb(137, 141, 212)",
    "NFB_PLEX": "rgb(255, 0, 255)",
    "NFIB": "rgb(125, 199, 202)",
    "NFIB_PLEX": "rgb(253, 179, 6)",
    "NSCLC": "rgb(253, 73, 74)",
    "NSCLC_AD": "rgb(213, 0, 233)",
    "NSCLC_AD_CELLC": "rgb(179, 1, 243)",
    "NSCLC_SC": "rgb(99, 253, 156)",
    "NSCLC_SC_CELLC": "rgb(254, 216, 190)",
    "NUTMID_CA": "rgb(223, 49, 139)",
    "OB": "rgb(238, 254, 53)",
    "OFMT": "rgb(8, 177, 250)",
    "OS_CONV": "rgb(43, 172, 68)",
    "OS_HG": "rgb(112, 49, 248)",
    "OVA_CA": "rgb(0, 128, 0)",
    "OVA_CA_CELLC": "rgb(162, 222, 100)",
    "O_IDH": "rgb(228, 134, 202)",
    "O_IDH_ANA": "rgb(16, 57, 27)",
    "PAN_CA": "rgb(253, 89, 3)",
    "PAN_CA_CELLC": "rgb(204, 50, 184)",
    "PGG_EXAD": "rgb(106, 103, 29)",
    "PGG_EXAD_CELLC": "rgb(185, 126, 204)",
    "PGG_NC": "rgb(253, 73, 74)",
    "PHEO": "rgb(27, 238, 154)",
    "PHYT_BEN": "rgb(255, 0, 255)",
    "PHYT_BOR": "rgb(191, 249, 253)",
    "PHYT_MAL": "rgb(124, 188, 249)",
    "PHYT_NOS": "rgb(216, 5, 175)",
    "PIN_T_PB_A": "rgb(233, 221, 113)",
    "PIN_T_PB_B": "rgb(118, 188, 19)",
    "PIN_T_PPT": "rgb(150, 203, 163)",
    "PITAD": "rgb(89, 115, 252)",
    "PITAD_ACTH": "rgb(2, 31, 205)",
    "PITAD_FSH_LH": "rgb(172, 204, 55)",
    "PITAD_PRL": "rgb(166, 73, 172)",
    "PITAD_STH_DNS_A": "rgb(216, 5, 94)",
    "PITAD_STH_DNS_B": "rgb(199, 208, 201)",
    "PITAD_STH_SPA": "rgb(255, 0, 255)",
    "PITAD_TSH": "rgb(166, 186, 118)",
    "PITUI_SCO_GCT": "rgb(62, 123, 8)",
    "PLASMA": "rgb(46, 35, 211)",
    "PLEX_AD": "rgb(224, 26, 46)",
    "PLEX_PED_A": "rgb(30, 151, 115)",
    "PLEX_PED_B": "rgb(76, 159, 211)",
    "PMBCL": "rgb(223, 49, 139)",
    "PNST_NF_BO": "rgb(55, 24, 251)",
    "PR_CA": "rgb(114, 194, 122)",
    "PR_CA_CELLC": "rgb(238, 254, 53)",
    "PTLD_DLBCL_EBV": "rgb(128, 0, 0)",
    "PTPR_A": "rgb(211, 138, 71)",
    "PTPR_B": "rgb(105, 1, 63)",
    "PXA": "rgb(207, 189, 7)",
    "RCC_CC": "rgb(3, 171, 6)",
    "RCC_CC_CELLC": "rgb(255, 1, 62)",
    "RCC_CP": "rgb(249, 207, 251)",
    "RCC_CP_CELLC": "rgb(99, 253, 156)",
    "RCC_PAP": "rgb(156, 4, 166)",
    "RCC_PAP_CELLC": "rgb(10, 89, 60)",
    "RETB": "rgb(49, 62, 123)",
    "RMS_ALV": "rgb(115, 32, 35)",
    "RMS_EMB": "rgb(254, 41, 255)",
    "RMS_MYOD1": "rgb(181, 251, 132)",
    "SARC_CELLC": "rgb(114, 48, 118)",
    "SARC_MPNST-like": "rgb(150, 2, 52)",
    "SARC_NOS": "rgb(72, 95, 218)",
    "SARC_PSPIN": "rgb(209, 241, 7)",
    "SARC_RMS-like": "rgb(211, 138, 71)",
    "SBRCT_BCOR": "rgb(129, 154, 59)",
    "SBRCT_CIC": "rgb(8, 177, 250)",
    "SCC_CUT": "rgb(233, 221, 113)",
    "SCHW": "rgb(55, 161, 2)",
    "SCHW_MEL": "rgb(177, 147, 240)",
    "SCLC": "rgb(9, 43, 74)",
    "SEF": "rgb(88, 127, 95)",
    "SEMIN": "rgb(115, 32, 35)",
    "SFT": "rgb(207, 189, 7)",
    "SFT_HMPC": "rgb(39, 247, 32)",
    "SFT_HMPC_MAL": "rgb(69, 1, 215)",
    "SKM_ALS": "rgb(179, 254, 183)",
    "SKM_CONTR": "rgb(8, 177, 250)",
    "SKM_IBM": "rgb(23, 84, 134)",
    "SKM_INF": "rgb(114, 48, 118)",
    "SKM_MCA": "rgb(128, 255, 0)",
    "SKM_NEKR": "rgb(1, 11, 100)",
    "SKM_NMA": "rgb(207, 85, 148)",
    "SKM_PM": "rgb(8, 5, 166)",
    "SKM_POM": "rgb(248, 217, 8)",
    "SPC_REACT": "rgb(246, 165, 255)",
    "STOM_CA": "rgb(0, 255, 255)",
    "STOM_CA_CELLC": "rgb(249, 207, 251)",
    "SUBEPN_PF": "rgb(227, 65, 2)",
    "SUBEPN_SPINE": "rgb(3, 171, 6)",
    "SUBEPN_ST": "rgb(76, 159, 211)",
    "SWN": "rgb(130, 34, 185)",
    "SYSA": "rgb(112, 49, 248)",
    "TCL_NOS": "rgb(147, 20, 253)",
    "TGCT_CELLC": "rgb(218, 21, 138)",
    "THYMO": "rgb(157, 162, 1)",
    "THYMO_A": "rgb(62, 123, 8)",
    "THYMO_AB": "rgb(43, 172, 68)",
    "THYMO_B1": "rgb(166, 186, 118)",
    "THYMO_B2": "rgb(27, 90, 248)",
    "THYMO_B3": "rgb(128, 0, 0)",
    "THYMO_C": "rgb(247, 214, 61)",
    "THYMO_CELLC": "rgb(173, 185, 14)",
    "THYR_CA": "rgb(181, 251, 132)",
    "THYR_CA_CELLC": "rgb(175, 141, 95)",
    "THYR_CA_FOL": "rgb(239, 154, 22)",
    "THYR_CA_PAP": "rgb(156, 98, 254)",
    "THYR_CA_TAL": "rgb(184, 92, 84)",
    "UCS": "rgb(255, 0, 255)",
    "UCS_CELLC": "rgb(52, 253, 118)",
    "UPS": "rgb(172, 47, 221)",
    "USARC": "rgb(30, 151, 115)",
    "WDLS_DDLS": "rgb(233, 221, 113)",
    "YST_T": "rgb(5, 231, 67)",
}
